@@ -1,5 +1,5 @@
 estep.W <-
-function(X,alpha,beta,mu,a,b,d,Q,Z){
+function(X,alpha,beta,mu,a,b,d,Q,Z,Wmat){
   ## Initialization
   K = length(alpha); L =length(beta)
   P = matrix(NA,ncol(X),L)
@@ -8,8 +8,8 @@ function(X,alpha,beta,mu,a,b,d,Q,Z){
     A = matrix(NA,nrow(X),ncol(X))
     for (k in 1:K){
       Xk = X[Z[,k]==1,,]
-      if (sum(Z[,k])==1) A[Z[,k]==1,] = estep.W.cost(Xk,alpha,beta,mu,a,b,d,Q,k,l)
-      else A[Z[,k]==1,] = apply(Xk,2,estep.W.cost,alpha,beta,mu,a,b,d,Q,k,l)
+      if (sum(Z[,k])==1) A[Z[,k]==1,] = estep.W.cost(Xk,alpha,beta,mu,a,b,d,Q,k,l,Wmat)
+      else A[Z[,k]==1,] = apply(Xk,2,estep.W.cost,alpha,beta,mu,a,b,d,Q,k,l,Wmat)
     }
     P[,l] = colSums(-1/2*A)
   }
